##  Prerequisites
  * You have admin access to your IdP. If you don't have access, coordinate with your IT or identity management team to support you during the migration.
  * You have admin permissions in SAP LeanIX.
  * Keep your current admin session active. Don't close the current browser.
